Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(10)

Unified Diff: runtime/observatory/tests/service/positive_token_pos_test.dart

Issue 2767533002: Revert "Fix observatory tests broken by running dartfmt." (Closed)
Patch Set: Created 3 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: runtime/observatory/tests/service/positive_token_pos_test.dart
diff --git a/runtime/observatory/tests/service/positive_token_pos_test.dart b/runtime/observatory/tests/service/positive_token_pos_test.dart
index 05ef175d4b001e7ac54fad47c02799de0acb3d8c..c30da31d28dabe0a6bc81c64eaaf0189ea2d9dc5 100644
--- a/runtime/observatory/tests/service/positive_token_pos_test.dart
+++ b/runtime/observatory/tests/service/positive_token_pos_test.dart
@@ -9,20 +9,20 @@ import 'package:unittest/unittest.dart';
import 'service_test_common.dart';
import 'test_helper.dart';
-helper() async {
- // Line 12, Col 16 is the open brace.
+helper() async { // Line 12, Col 16 is the open brace.
}
testMain() {
debugger();
- helper(); // Line 18, Col 3 is the position of the function call.
+ helper(); // Line 17, Col 3 is the position of the function call.
}
var tests = [
hasStoppedAtBreakpoint,
markDartColonLibrariesDebuggable,
- stoppedAtLine(18),
+ stoppedAtLine(17),
stepInto,
+
(Isolate isolate) async {
ServiceMap stack = await isolate.getStack();
expect(stack['frames'].length, greaterThan(3));
@@ -41,7 +41,7 @@ var tests = [
frame = stack['frames'][2];
expect(frame.function.name, equals('testMain'));
- expect(await frame.location.getLine(), equals(18));
+ expect(await frame.location.getLine(), equals(17));
expect(await frame.location.getColumn(), equals(3));
}
];

Powered by Google App Engine
This is Rietveld 408576698